summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorBenjamin Valentin <[email protected]>2012-03-27 03:10:35 +0200
committerBenjamin Valentin <[email protected]>2012-03-27 03:10:35 +0200
commitf05bcc640f666acf756e7501ceefe1ad3cbf7e64 (patch)
tree85dab17a828f45f2897b9eff6883258de584e566 /src
parente214b332395adbc77ad596218895a4834cad434d (diff)
downloadcaja-dropbox-f05bcc640f666acf756e7501ceefe1ad3cbf7e64.tar.bz2
caja-dropbox-f05bcc640f666acf756e7501ceefe1ad3cbf7e64.tar.xz
run migrate script
Diffstat (limited to 'src')
-rw-r--r--src/Makefile.am26
-rw-r--r--src/Makefile.in174
-rw-r--r--src/async-io-coroutine.h8
-rw-r--r--src/caja-dropbox-hooks.c (renamed from src/nautilus-dropbox-hooks.c)34
-rw-r--r--src/caja-dropbox-hooks.h (renamed from src/nautilus-dropbox-hooks.h)32
-rw-r--r--src/caja-dropbox.c (renamed from src/nautilus-dropbox.c)226
-rw-r--r--src/caja-dropbox.h69
-rw-r--r--src/dropbox-client-util.c8
-rw-r--r--src/dropbox-client-util.h8
-rw-r--r--src/dropbox-client.c24
-rw-r--r--src/dropbox-client.h12
-rw-r--r--src/dropbox-command-client.c28
-rw-r--r--src/dropbox-command-client.h28
-rw-r--r--src/dropbox.c28
-rw-r--r--src/g-util.h8
-rw-r--r--src/nautilus-dropbox.h69
16 files changed, 391 insertions, 391 deletions
diff --git a/src/Makefile.am b/src/Makefile.am
index 54fb06a..016ecb9 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -2,30 +2,30 @@ INCLUDES = \
-I$(top_srcdir) \
-I$(top_builddir)
-nautilus_extensiondir=$(NAUTILUS_EXTENSION_DIR)
+caja_extensiondir=$(CAJA_EXTENSION_DIR)
-nautilus_extension_LTLIBRARIES=libnautilus-dropbox.la
+caja_extension_LTLIBRARIES=libcaja-dropbox.la
-libnautilus_dropbox_la_CFLAGS = \
+libcaja_dropbox_la_CFLAGS = \
-DDATADIR=\"$(datadir)\" \
-DEMBLEMDIR=\"$(EMBLEM_DIR)\" \
-Wall \
$(WARN_CFLAGS) \
$(DISABLE_DEPRECATED_CFLAGS) \
- $(NAUTILUS_CFLAGS) \
+ $(CAJA_CFLAGS) \
$(GLIB_CFLAGS)
if DEBUG
-libnautilus_dropbox_la_CFLAGS += -DND_DEBUG
+libcaja_dropbox_la_CFLAGS += -DND_DEBUG
else
-libnautilus_dropbox_la_CFLAGS += -DG_DISABLE_ASSERT -DG_DISABLE_CHECKS
+libcaja_dropbox_la_CFLAGS += -DG_DISABLE_ASSERT -DG_DISABLE_CHECKS
endif
-libnautilus_dropbox_la_SOURCES = \
- nautilus-dropbox.c \
- nautilus-dropbox.h \
- nautilus-dropbox-hooks.h \
- nautilus-dropbox-hooks.c \
+libcaja_dropbox_la_SOURCES = \
+ caja-dropbox.c \
+ caja-dropbox.h \
+ caja-dropbox-hooks.h \
+ caja-dropbox-hooks.c \
dropbox-command-client.h \
dropbox-command-client.c \
dropbox-client.c dropbox-client.h \
@@ -35,5 +35,5 @@ libnautilus_dropbox_la_SOURCES = \
dropbox-client-util.h \
dropbox.c
-libnautilus_dropbox_la_LDFLAGS = -module -avoid-version
-libnautilus_dropbox_la_LIBADD = $(NAUTILUS_LIBS) $(GLIB_LIBS)
+libcaja_dropbox_la_LDFLAGS = -module -avoid-version
+libcaja_dropbox_la_LIBADD = $(CAJA_LIBS) $(GLIB_LIBS)
diff --git a/src/Makefile.in b/src/Makefile.in
index 548e911..6813623 100644
--- a/src/Makefile.in
+++ b/src/Makefile.in
@@ -67,23 +67,23 @@ am__nobase_list = $(am__nobase_strip_setup); \
am__base_list = \
sed '$$!N;$$!N;$$!N;$$!N;$$!N;$$!N;$$!N;s/\n/ /g' | \
sed '$$!N;$$!N;$$!N;$$!N;s/\n/ /g'
-am__installdirs = "$(DESTDIR)$(nautilus_extensiondir)"
-LTLIBRARIES = $(nautilus_extension_LTLIBRARIES)
+am__installdirs = "$(DESTDIR)$(caja_extensiondir)"
+LTLIBRARIES = $(caja_extension_LTLIBRARIES)
am__DEPENDENCIES_1 =
-libnautilus_dropbox_la_DEPENDENCIES = $(am__DEPENDENCIES_1) \
+libcaja_dropbox_la_DEPENDENCIES = $(am__DEPENDENCIES_1) \
$(am__DEPENDENCIES_1)
-am_libnautilus_dropbox_la_OBJECTS = \
- libnautilus_dropbox_la-nautilus-dropbox.lo \
- libnautilus_dropbox_la-nautilus-dropbox-hooks.lo \
- libnautilus_dropbox_la-dropbox-command-client.lo \
- libnautilus_dropbox_la-dropbox-client.lo \
- libnautilus_dropbox_la-dropbox-client-util.lo \
- libnautilus_dropbox_la-dropbox.lo
-libnautilus_dropbox_la_OBJECTS = $(am_libnautilus_dropbox_la_OBJECTS)
-libnautilus_dropbox_la_LINK = $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) \
+am_libcaja_dropbox_la_OBJECTS = \
+ libcaja_dropbox_la-caja-dropbox.lo \
+ libcaja_dropbox_la-caja-dropbox-hooks.lo \
+ libcaja_dropbox_la-dropbox-command-client.lo \
+ libcaja_dropbox_la-dropbox-client.lo \
+ libcaja_dropbox_la-dropbox-client-util.lo \
+ libcaja_dropbox_la-dropbox.lo
+libcaja_dropbox_la_OBJECTS = $(am_libcaja_dropbox_la_OBJECTS)
+libcaja_dropbox_la_LINK = $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) \
$(LIBTOOLFLAGS) --mode=link $(CCLD) \
- $(libnautilus_dropbox_la_CFLAGS) $(CFLAGS) \
- $(libnautilus_dropbox_la_LDFLAGS) $(LDFLAGS) -o $@
+ $(libcaja_dropbox_la_CFLAGS) $(CFLAGS) \
+ $(libcaja_dropbox_la_LDFLAGS) $(LDFLAGS) -o $@
DEFAULT_INCLUDES = -I.@am__isrc@ -I$(top_builddir)
depcomp = $(SHELL) $(top_srcdir)/depcomp
am__depfiles_maybe = depfiles
@@ -97,8 +97,8 @@ CCLD = $(CC)
LINK = $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) \
--mode=link $(CCLD) $(AM_CFLAGS) $(CFLAGS) $(AM_LDFLAGS) \
$(LDFLAGS) -o $@
-SOURCES = $(libnautilus_dropbox_la_SOURCES)
-DIST_SOURCES = $(libnautilus_dropbox_la_SOURCES)
+SOURCES = $(libcaja_dropbox_la_SOURCES)
+DIST_SOURCES = $(libcaja_dropbox_la_SOURCES)
ETAGS = etags
CTAGS = ctags
DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -145,9 +145,9 @@ LN_S = @LN_S@
LTLIBOBJS = @LTLIBOBJS@
MAKEINFO = @MAKEINFO@
MKDIR_P = @MKDIR_P@
-NAUTILUS_CFLAGS = @NAUTILUS_CFLAGS@
-NAUTILUS_EXTENSION_DIR = @NAUTILUS_EXTENSION_DIR@
-NAUTILUS_LIBS = @NAUTILUS_LIBS@
+CAJA_CFLAGS = @CAJA_CFLAGS@
+CAJA_EXTENSION_DIR = @CAJA_EXTENSION_DIR@
+CAJA_LIBS = @CAJA_LIBS@
NM = @NM@
NMEDIT = @NMEDIT@
OBJDUMP = @OBJDUMP@
@@ -227,17 +227,17 @@ INCLUDES = \
-I$(top_srcdir) \
-I$(top_builddir)
-nautilus_extensiondir = $(NAUTILUS_EXTENSION_DIR)
-nautilus_extension_LTLIBRARIES = libnautilus-dropbox.la
-libnautilus_dropbox_la_CFLAGS = -DDATADIR=\"$(datadir)\" \
+caja_extensiondir = $(CAJA_EXTENSION_DIR)
+caja_extension_LTLIBRARIES = libcaja-dropbox.la
+libcaja_dropbox_la_CFLAGS = -DDATADIR=\"$(datadir)\" \
-DEMBLEMDIR=\"$(EMBLEM_DIR)\" -Wall $(WARN_CFLAGS) \
- $(DISABLE_DEPRECATED_CFLAGS) $(NAUTILUS_CFLAGS) $(GLIB_CFLAGS) \
+ $(DISABLE_DEPRECATED_CFLAGS) $(CAJA_CFLAGS) $(GLIB_CFLAGS) \
$(am__append_1) $(am__append_2)
-libnautilus_dropbox_la_SOURCES = \
- nautilus-dropbox.c \
- nautilus-dropbox.h \
- nautilus-dropbox-hooks.h \
- nautilus-dropbox-hooks.c \
+libcaja_dropbox_la_SOURCES = \
+ caja-dropbox.c \
+ caja-dropbox.h \
+ caja-dropbox-hooks.h \
+ caja-dropbox-hooks.c \
dropbox-command-client.h \
dropbox-command-client.c \
dropbox-client.c dropbox-client.h \
@@ -247,8 +247,8 @@ libnautilus_dropbox_la_SOURCES = \
dropbox-client-util.h \
dropbox.c
-libnautilus_dropbox_la_LDFLAGS = -module -avoid-version
-libnautilus_dropbox_la_LIBADD = $(NAUTILUS_LIBS) $(GLIB_LIBS)
+libcaja_dropbox_la_LDFLAGS = -module -avoid-version
+libcaja_dropbox_la_LIBADD = $(CAJA_LIBS) $(GLIB_LIBS)
all: all-am
.SUFFIXES:
@@ -283,39 +283,39 @@ $(top_srcdir)/configure: $(am__configure_deps)
$(ACLOCAL_M4): $(am__aclocal_m4_deps)
cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
$(am__aclocal_m4_deps):
-install-nautilus_extensionLTLIBRARIES: $(nautilus_extension_LTLIBRARIES)
+install-caja_extensionLTLIBRARIES: $(caja_extension_LTLIBRARIES)
@$(NORMAL_INSTALL)
- test -z "$(nautilus_extensiondir)" || $(MKDIR_P) "$(DESTDIR)$(nautilus_extensiondir)"
- @list='$(nautilus_extension_LTLIBRARIES)'; test -n "$(nautilus_extensiondir)" || list=; \
+ test -z "$(caja_extensiondir)" || $(MKDIR_P) "$(DESTDIR)$(caja_extensiondir)"
+ @list='$(caja_extension_LTLIBRARIES)'; test -n "$(caja_extensiondir)" || list=; \
list2=; for p in $$list; do \
if test -f $$p; then \
list2="$$list2 $$p"; \
else :; fi; \
done; \
test -z "$$list2" || { \
- echo " $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=install $(INSTALL) $(INSTALL_STRIP_FLAG) $$list2 '$(DESTDIR)$(nautilus_extensiondir)'"; \
- $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=install $(INSTALL) $(INSTALL_STRIP_FLAG) $$list2 "$(DESTDIR)$(nautilus_extensiondir)"; \
+ echo " $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=install $(INSTALL) $(INSTALL_STRIP_FLAG) $$list2 '$(DESTDIR)$(caja_extensiondir)'"; \
+ $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=install $(INSTALL) $(INSTALL_STRIP_FLAG) $$list2 "$(DESTDIR)$(caja_extensiondir)"; \
}
-uninstall-nautilus_extensionLTLIBRARIES:
+uninstall-caja_extensionLTLIBRARIES:
@$(NORMAL_UNINSTALL)
- @list='$(nautilus_extension_LTLIBRARIES)'; test -n "$(nautilus_extensiondir)" || list=; \
+ @list='$(caja_extension_LTLIBRARIES)'; test -n "$(caja_extensiondir)" || list=; \
for p in $$list; do \
$(am__strip_dir) \
- echo " $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=uninstall rm -f '$(DESTDIR)$(nautilus_extensiondir)/$$f'"; \
- $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=uninstall rm -f "$(DESTDIR)$(nautilus_extensiondir)/$$f"; \
+ echo " $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=uninstall rm -f '$(DESTDIR)$(caja_extensiondir)/$$f'"; \
+ $(LIBTOOL) $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=uninstall rm -f "$(DESTDIR)$(caja_extensiondir)/$$f"; \
done
-clean-nautilus_extensionLTLIBRARIES:
- -test -z "$(nautilus_extension_LTLIBRARIES)" || rm -f $(nautilus_extension_LTLIBRARIES)
- @list='$(nautilus_extension_LTLIBRARIES)'; for p in $$list; do \
+clean-caja_extensionLTLIBRARIES:
+ -test -z "$(caja_extension_LTLIBRARIES)" || rm -f $(caja_extension_LTLIBRARIES)
+ @list='$(caja_extension_LTLIBRARIES)'; for p in $$list; do \
dir="`echo $$p | sed -e 's|/[^/]*$$||'`"; \
test "$$dir" != "$$p" || dir=.; \
echo "rm -f \"$${dir}/so_locations\""; \
rm -f "$${dir}/so_locations"; \
done
-libnautilus-dropbox.la: $(libnautilus_dropbox_la_OBJECTS) $(libnautilus_dropbox_la_DEPENDENCIES)
- $(libnautilus_dropbox_la_LINK) -rpath $(nautilus_extensiondir) $(libnautilus_dropbox_la_OBJECTS) $(libnautilus_dropbox_la_LIBADD) $(LIBS)
+libcaja-dropbox.la: $(libcaja_dropbox_la_OBJECTS) $(libcaja_dropbox_la_DEPENDENCIES)
+ $(libcaja_dropbox_la_LINK) -rpath $(caja_extensiondir) $(libcaja_dropbox_la_OBJECTS) $(libcaja_dropbox_la_LIBADD) $(LIBS)
mostlyclean-compile:
-rm -f *.$(OBJEXT)
@@ -323,12 +323,12 @@ mostlyclean-compile:
distclean-compile:
-rm -f *.tab.c
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libnautilus_dropbox_la-dropbox-client-util.Plo@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libnautilus_dropbox_la-dropbox-client.Plo@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libnautilus_dropbox_la-dropbox-command-client.Plo@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libnautilus_dropbox_la-dropbox.Plo@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libnautilus_dropbox_la-nautilus-dropbox-hooks.Plo@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libnautilus_dropbox_la-nautilus-dropbox.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libcaja_dropbox_la-dropbox-client-util.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libcaja_dropbox_la-dropbox-client.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libcaja_dropbox_la-dropbox-command-client.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libcaja_dropbox_la-dropbox.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libcaja_dropbox_la-caja-dropbox-hooks.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/libcaja_dropbox_la-caja-dropbox.Plo@am__quote@
.c.o:
@am__fastdepCC_TRUE@ $(COMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ $<
@@ -351,47 +351,47 @@ distclean-compile:
@AMDEP_TRUE@@am__fastdepCC_FALSE@ DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
@am__fastdepCC_FALSE@ $(LTCOMPILE) -c -o $@ $<
-libnautilus_dropbox_la-nautilus-dropbox.lo: nautilus-dropbox.c
-@am__fastdepCC_TRUE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libnautilus_dropbox_la_CFLAGS) $(CFLAGS) -MT libnautilus_dropbox_la-nautilus-dropbox.lo -MD -MP -MF $(DEPDIR)/libnautilus_dropbox_la-nautilus-dropbox.Tpo -c -o libnautilus_dropbox_la-nautilus-dropbox.lo `test -f 'nautilus-dropbox.c' || echo '$(srcdir)/'`nautilus-dropbox.c
-@am__fastdepCC_TRUE@ $(am__mv) $(DEPDIR)/libnautilus_dropbox_la-nautilus-dropbox.Tpo $(DEPDIR)/libnautilus_dropbox_la-nautilus-dropbox.Plo
-@AMDEP_TRUE@@am__fastdepCC_FALSE@ source='nautilus-dropbox.c' object='libnautilus_dropbox_la-nautilus-dropbox.lo' libtool=yes @AMDEPBACKSLASH@
+libcaja_dropbox_la-caja-dropbox.lo: caja-dropbox.c
+@am__fastdepCC_TRUE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libcaja_dropbox_la_CFLAGS) $(CFLAGS) -MT libcaja_dropbox_la-caja-dropbox.lo -MD -MP -MF $(DEPDIR)/libcaja_dropbox_la-caja-dropbox.Tpo -c -o libcaja_dropbox_la-caja-dropbox.lo `test -f 'caja-dropbox.c' || echo '$(srcdir)/'`caja-dropbox.c
+@am__fastdepCC_TRUE@ $(am__mv) $(DEPDIR)/libcaja_dropbox_la-caja-dropbox.Tpo $(DEPDIR)/libcaja_dropbox_la-caja-dropbox.Plo
+@AMDEP_TRUE@@am__fastdepCC_FALSE@ source='caja-dropbox.c' object='libcaja_dropbox_la-caja-dropbox.lo' libtool=yes @AMDEPBACKSLASH@
@AMDEP_TRUE@@am__fastdepCC_FALSE@ DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libnautilus_dropbox_la_CFLAGS) $(CFLAGS) -c -o libnautilus_dropbox_la-nautilus-dropbox.lo `test -f 'nautilus-dropbox.c' || echo '$(srcdir)/'`nautilus-dropbox.c
+@am__fastdepCC_FALSE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libcaja_dropbox_la_CFLAGS) $(CFLAGS) -c -o libcaja_dropbox_la-caja-dropbox.lo `test -f 'caja-dropbox.c' || echo '$(srcdir)/'`caja-dropbox.c
-libnautilus_dropbox_la-nautilus-dropbox-hooks.lo: nautilus-dropbox-hooks.c
-@am__fastdepCC_TRUE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libnautilus_dropbox_la_CFLAGS) $(CFLAGS) -MT libnautilus_dropbox_la-nautilus-dropbox-hooks.lo -MD -MP -MF $(DEPDIR)/libnautilus_dropbox_la-nautilus-dropbox-hooks.Tpo -c -o libnautilus_dropbox_la-nautilus-dropbox-hooks.lo `test -f 'nautilus-dropbox-hooks.c' || echo '$(srcdir)/'`nautilus-dropbox-hooks.c
-@am__fastdepCC_TRUE@ $(am__mv) $(DEPDIR)/libnautilus_dropbox_la-nautilus-dropbox-hooks.Tpo $(DEPDIR)/libnautilus_dropbox_la-nautilus-dropbox-hooks.Plo
-@AMDEP_TRUE@@am__fastdepCC_FALSE@ source='nautilus-dropbox-hooks.c' object='libnautilus_dropbox_la-nautilus-dropbox-hooks.lo' libtool=yes @AMDEPBACKSLASH@
+libcaja_dropbox_la-caja-dropbox-hooks.lo: caja-dropbox-hooks.c
+@am__fastdepCC_TRUE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libcaja_dropbox_la_CFLAGS) $(CFLAGS) -MT libcaja_dropbox_la-caja-dropbox-hooks.lo -MD -MP -MF $(DEPDIR)/libcaja_dropbox_la-caja-dropbox-hooks.Tpo -c -o libcaja_dropbox_la-caja-dropbox-hooks.lo `test -f 'caja-dropbox-hooks.c' || echo '$(srcdir)/'`caja-dropbox-hooks.c
+@am__fastdepCC_TRUE@ $(am__mv) $(DEPDIR)/libcaja_dropbox_la-caja-dropbox-hooks.Tpo $(DEPDIR)/libcaja_dropbox_la-caja-dropbox-hooks.Plo
+@AMDEP_TRUE@@am__fastdepCC_FALSE@ source='caja-dropbox-hooks.c' object='libcaja_dropbox_la-caja-dropbox-hooks.lo' libtool=yes @AMDEPBACKSLASH@
@AMDEP_TRUE@@am__fastdepCC_FALSE@ DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libnautilus_dropbox_la_CFLAGS) $(CFLAGS) -c -o libnautilus_dropbox_la-nautilus-dropbox-hooks.lo `test -f 'nautilus-dropbox-hooks.c' || echo '$(srcdir)/'`nautilus-dropbox-hooks.c
+@am__fastdepCC_FALSE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libcaja_dropbox_la_CFLAGS) $(CFLAGS) -c -o libcaja_dropbox_la-caja-dropbox-hooks.lo `test -f 'caja-dropbox-hooks.c' || echo '$(srcdir)/'`caja-dropbox-hooks.c
-libnautilus_dropbox_la-dropbox-command-client.lo: dropbox-command-client.c
-@am__fastdepCC_TRUE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libnautilus_dropbox_la_CFLAGS) $(CFLAGS) -MT libnautilus_dropbox_la-dropbox-command-client.lo -MD -MP -MF $(DEPDIR)/libnautilus_dropbox_la-dropbox-command-client.Tpo -c -o libnautilus_dropbox_la-dropbox-command-client.lo `test -f 'dropbox-command-client.c' || echo '$(srcdir)/'`dropbox-command-client.c
-@am__fastdepCC_TRUE@ $(am__mv) $(DEPDIR)/libnautilus_dropbox_la-dropbox-command-client.Tpo $(DEPDIR)/libnautilus_dropbox_la-dropbox-command-client.Plo
-@AMDEP_TRUE@@am__fastdepCC_FALSE@ source='dropbox-command-client.c' object='libnautilus_dropbox_la-dropbox-command-client.lo' libtool=yes @AMDEPBACKSLASH@
+libcaja_dropbox_la-dropbox-command-client.lo: dropbox-command-client.c
+@am__fastdepCC_TRUE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libcaja_dropbox_la_CFLAGS) $(CFLAGS) -MT libcaja_dropbox_la-dropbox-command-client.lo -MD -MP -MF $(DEPDIR)/libcaja_dropbox_la-dropbox-command-client.Tpo -c -o libcaja_dropbox_la-dropbox-command-client.lo `test -f 'dropbox-command-client.c' || echo '$(srcdir)/'`dropbox-command-client.c
+@am__fastdepCC_TRUE@ $(am__mv) $(DEPDIR)/libcaja_dropbox_la-dropbox-command-client.Tpo $(DEPDIR)/libcaja_dropbox_la-dropbox-command-client.Plo
+@AMDEP_TRUE@@am__fastdepCC_FALSE@ source='dropbox-command-client.c' object='libcaja_dropbox_la-dropbox-command-client.lo' libtool=yes @AMDEPBACKSLASH@
@AMDEP_TRUE@@am__fastdepCC_FALSE@ DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libnautilus_dropbox_la_CFLAGS) $(CFLAGS) -c -o libnautilus_dropbox_la-dropbox-command-client.lo `test -f 'dropbox-command-client.c' || echo '$(srcdir)/'`dropbox-command-client.c
+@am__fastdepCC_FALSE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libcaja_dropbox_la_CFLAGS) $(CFLAGS) -c -o libcaja_dropbox_la-dropbox-command-client.lo `test -f 'dropbox-command-client.c' || echo '$(srcdir)/'`dropbox-command-client.c
-libnautilus_dropbox_la-dropbox-client.lo: dropbox-client.c
-@am__fastdepCC_TRUE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libnautilus_dropbox_la_CFLAGS) $(CFLAGS) -MT libnautilus_dropbox_la-dropbox-client.lo -MD -MP -MF $(DEPDIR)/libnautilus_dropbox_la-dropbox-client.Tpo -c -o libnautilus_dropbox_la-dropbox-client.lo `test -f 'dropbox-client.c' || echo '$(srcdir)/'`dropbox-client.c
-@am__fastdepCC_TRUE@ $(am__mv) $(DEPDIR)/libnautilus_dropbox_la-dropbox-client.Tpo $(DEPDIR)/libnautilus_dropbox_la-dropbox-client.Plo
-@AMDEP_TRUE@@am__fastdepCC_FALSE@ source='dropbox-client.c' object='libnautilus_dropbox_la-dropbox-client.lo' libtool=yes @AMDEPBACKSLASH@
+libcaja_dropbox_la-dropbox-client.lo: dropbox-client.c
+@am__fastdepCC_TRUE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libcaja_dropbox_la_CFLAGS) $(CFLAGS) -MT libcaja_dropbox_la-dropbox-client.lo -MD -MP -MF $(DEPDIR)/libcaja_dropbox_la-dropbox-client.Tpo -c -o libcaja_dropbox_la-dropbox-client.lo `test -f 'dropbox-client.c' || echo '$(srcdir)/'`dropbox-client.c
+@am__fastdepCC_TRUE@ $(am__mv) $(DEPDIR)/libcaja_dropbox_la-dropbox-client.Tpo $(DEPDIR)/libcaja_dropbox_la-dropbox-client.Plo
+@AMDEP_TRUE@@am__fastdepCC_FALSE@ source='dropbox-client.c' object='libcaja_dropbox_la-dropbox-client.lo' libtool=yes @AMDEPBACKSLASH@
@AMDEP_TRUE@@am__fastdepCC_FALSE@ DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libnautilus_dropbox_la_CFLAGS) $(CFLAGS) -c -o libnautilus_dropbox_la-dropbox-client.lo `test -f 'dropbox-client.c' || echo '$(srcdir)/'`dropbox-client.c
+@am__fastdepCC_FALSE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libcaja_dropbox_la_CFLAGS) $(CFLAGS) -c -o libcaja_dropbox_la-dropbox-client.lo `test -f 'dropbox-client.c' || echo '$(srcdir)/'`dropbox-client.c
-libnautilus_dropbox_la-dropbox-client-util.lo: dropbox-client-util.c
-@am__fastdepCC_TRUE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libnautilus_dropbox_la_CFLAGS) $(CFLAGS) -MT libnautilus_dropbox_la-dropbox-client-util.lo -MD -MP -MF $(DEPDIR)/libnautilus_dropbox_la-dropbox-client-util.Tpo -c -o libnautilus_dropbox_la-dropbox-client-util.lo `test -f 'dropbox-client-util.c' || echo '$(srcdir)/'`dropbox-client-util.c
-@am__fastdepCC_TRUE@ $(am__mv) $(DEPDIR)/libnautilus_dropbox_la-dropbox-client-util.Tpo $(DEPDIR)/libnautilus_dropbox_la-dropbox-client-util.Plo
-@AMDEP_TRUE@@am__fastdepCC_FALSE@ source='dropbox-client-util.c' object='libnautilus_dropbox_la-dropbox-client-util.lo' libtool=yes @AMDEPBACKSLASH@
+libcaja_dropbox_la-dropbox-client-util.lo: dropbox-client-util.c
+@am__fastdepCC_TRUE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libcaja_dropbox_la_CFLAGS) $(CFLAGS) -MT libcaja_dropbox_la-dropbox-client-util.lo -MD -MP -MF $(DEPDIR)/libcaja_dropbox_la-dropbox-client-util.Tpo -c -o libcaja_dropbox_la-dropbox-client-util.lo `test -f 'dropbox-client-util.c' || echo '$(srcdir)/'`dropbox-client-util.c
+@am__fastdepCC_TRUE@ $(am__mv) $(DEPDIR)/libcaja_dropbox_la-dropbox-client-util.Tpo $(DEPDIR)/libcaja_dropbox_la-dropbox-client-util.Plo
+@AMDEP_TRUE@@am__fastdepCC_FALSE@ source='dropbox-client-util.c' object='libcaja_dropbox_la-dropbox-client-util.lo' libtool=yes @AMDEPBACKSLASH@
@AMDEP_TRUE@@am__fastdepCC_FALSE@ DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libnautilus_dropbox_la_CFLAGS) $(CFLAGS) -c -o libnautilus_dropbox_la-dropbox-client-util.lo `test -f 'dropbox-client-util.c' || echo '$(srcdir)/'`dropbox-client-util.c
+@am__fastdepCC_FALSE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libcaja_dropbox_la_CFLAGS) $(CFLAGS) -c -o libcaja_dropbox_la-dropbox-client-util.lo `test -f 'dropbox-client-util.c' || echo '$(srcdir)/'`dropbox-client-util.c
-libnautilus_dropbox_la-dropbox.lo: dropbox.c
-@am__fastdepCC_TRUE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libnautilus_dropbox_la_CFLAGS) $(CFLAGS) -MT libnautilus_dropbox_la-dropbox.lo -MD -MP -MF $(DEPDIR)/libnautilus_dropbox_la-dropbox.Tpo -c -o libnautilus_dropbox_la-dropbox.lo `test -f 'dropbox.c' || echo '$(srcdir)/'`dropbox.c
-@am__fastdepCC_TRUE@ $(am__mv) $(DEPDIR)/libnautilus_dropbox_la-dropbox.Tpo $(DEPDIR)/libnautilus_dropbox_la-dropbox.Plo
-@AMDEP_TRUE@@am__fastdepCC_FALSE@ source='dropbox.c' object='libnautilus_dropbox_la-dropbox.lo' libtool=yes @AMDEPBACKSLASH@
+libcaja_dropbox_la-dropbox.lo: dropbox.c
+@am__fastdepCC_TRUE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libcaja_dropbox_la_CFLAGS) $(CFLAGS) -MT libcaja_dropbox_la-dropbox.lo -MD -MP -MF $(DEPDIR)/libcaja_dropbox_la-dropbox.Tpo -c -o libcaja_dropbox_la-dropbox.lo `test -f 'dropbox.c' || echo '$(srcdir)/'`dropbox.c
+@am__fastdepCC_TRUE@ $(am__mv) $(DEPDIR)/libcaja_dropbox_la-dropbox.Tpo $(DEPDIR)/libcaja_dropbox_la-dropbox.Plo
+@AMDEP_TRUE@@am__fastdepCC_FALSE@ source='dropbox.c' object='libcaja_dropbox_la-dropbox.lo' libtool=yes @AMDEPBACKSLASH@
@AMDEP_TRUE@@am__fastdepCC_FALSE@ DEPDIR=$(DEPDIR) $(CCDEPMODE) $(depcomp) @AMDEPBACKSLASH@
-@am__fastdepCC_FALSE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libnautilus_dropbox_la_CFLAGS) $(CFLAGS) -c -o libnautilus_dropbox_la-dropbox.lo `test -f 'dropbox.c' || echo '$(srcdir)/'`dropbox.c
+@am__fastdepCC_FALSE@ $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) --mode=compile $(CC) $(DEFS) $(DEFAULT_INCLUDES) $(INCLUDES) $(AM_CPPFLAGS) $(CPPFLAGS) $(libcaja_dropbox_la_CFLAGS) $(CFLAGS) -c -o libcaja_dropbox_la-dropbox.lo `test -f 'dropbox.c' || echo '$(srcdir)/'`dropbox.c
mostlyclean-libtool:
-rm -f *.lo
@@ -485,7 +485,7 @@ check-am: all-am
check: check-am
all-am: Makefile $(LTLIBRARIES)
installdirs:
- for dir in "$(DESTDIR)$(nautilus_extensiondir)"; do \
+ for dir in "$(DESTDIR)$(caja_extensiondir)"; do \
test -z "$$dir" || $(MKDIR_P) "$$dir"; \
done
install: install-am
@@ -516,7 +516,7 @@ maintainer-clean-generic:
clean: clean-am
clean-am: clean-generic clean-libtool \
- clean-nautilus_extensionLTLIBRARIES mostlyclean-am
+ clean-caja_extensionLTLIBRARIES mostlyclean-am
distclean: distclean-am
-rm -rf ./$(DEPDIR)
@@ -536,7 +536,7 @@ info: info-am
info-am:
-install-data-am: install-nautilus_extensionLTLIBRARIES
+install-data-am: install-caja_extensionLTLIBRARIES
install-dvi: install-dvi-am
@@ -582,25 +582,25 @@ ps: ps-am
ps-am:
-uninstall-am: uninstall-nautilus_extensionLTLIBRARIES
+uninstall-am: uninstall-caja_extensionLTLIBRARIES
.MAKE: install-am install-strip
.PHONY: CTAGS GTAGS all all-am check check-am clean clean-generic \
- clean-libtool clean-nautilus_extensionLTLIBRARIES ctags \
+ clean-libtool clean-caja_extensionLTLIBRARIES ctags \
distclean distclean-compile distclean-generic \
distclean-libtool distclean-tags distdir dvi dvi-am html \
html-am info info-am install install-am install-data \
install-data-am install-dvi install-dvi-am install-exec \
install-exec-am install-html install-html-am install-info \
install-info-am install-man \
- install-nautilus_extensionLTLIBRARIES install-pdf \
+ install-caja_extensionLTLIBRARIES install-pdf \
install-pdf-am install-ps install-ps-am install-strip \
installcheck installcheck-am installdirs maintainer-clean \
maintainer-clean-generic mostlyclean mostlyclean-compile \
mostlyclean-generic mostlyclean-libtool pdf pdf-am ps ps-am \
tags uninstall uninstall-am \
- uninstall-nautilus_extensionLTLIBRARIES
+ uninstall-caja_extensionLTLIBRARIES
# Tell versions [3.59,3.63) of GNU make to not export all variables.
diff --git a/src/async-io-coroutine.h b/src/async-io-coroutine.h
index 125d84e..3e27bf4 100644
--- a/src/async-io-coroutine.h
+++ b/src/async-io-coroutine.h
@@ -4,20 +4,20 @@
* async-io-coroutine.h
* Macros to simplify writing coroutines for the glib main loop.
*
- * This file is part of nautilus-dropbox.
+ * This file is part of caja-dropbox.
*
- * nautilus-dropbox is free software: you can redistribute it and/or modify
+ * caja-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
- * nautilus-dropbox is distributed in the hope that it will be useful,
+ * caja-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with nautilus-dropbox. If not, see <http://www.gnu.org/licenses/>.
+ * along with caja-dropbox. If not, see <http://www.gnu.org/licenses/>.
*
*/
diff --git a/src/nautilus-dropbox.c b/src/caja-dropbox.c
index 86a0e8a..6451015 100644
--- a/src/nautilus-dropbox.c
+++ b/src/caja-dropbox.c
@@ -1,23 +1,23 @@
/*
* Copyright 2008 Evenflow, Inc.
*
- * nautilus-dropbox.c
- * Implements the Nautilus extension API for Dropbox.
+ * caja-dropbox.c
+ * Implements the Caja extension API for Dropbox.
*
- * This file is part of nautilus-dropbox.
+ * This file is part of caja-dropbox.
*
- * nautilus-dropbox is free software: you can redistribute it and/or modify
+ * caja-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
- * nautilus-dropbox is distributed in the hope that it will be useful,
+ * caja-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with nautilus-dropbox. If not, see <http://www.gnu.org/licenses/>.
+ * along with caja-dropbox. If not, see <http://www.gnu.org/licenses/>.
*
*/
@@ -37,19 +37,19 @@
#include <glib-object.h>
#include <gtk/gtk.h>
-#include <libnautilus-extension/nautilus-extension-types.h>
-#include <libnautilus-extension/nautilus-menu-provider.h>
-#include <libnautilus-extension/nautilus-info-provider.h>
+#include <libcaja-extension/caja-extension-types.h>
+#include <libcaja-extension/caja-menu-provider.h>
+#include <libcaja-extension/caja-info-provider.h>
#include "g-util.h"
#include "dropbox-command-client.h"
-#include "nautilus-dropbox.h"
-#include "nautilus-dropbox-hooks.h"
+#include "caja-dropbox.h"
+#include "caja-dropbox-hooks.h"
static char *emblems[] = {"dropbox-uptodate", "dropbox-syncing", "dropbox-unsyncable"};
gchar *DEFAULT_EMBLEM_PATHS[2] = { EMBLEMDIR , NULL };
-gboolean dropbox_use_nautilus_submenu_workaround;
+gboolean dropbox_use_caja_submenu_workaround;
gboolean dropbox_use_operation_in_progress_workaround;
static GType dropbox_type = 0;
@@ -99,13 +99,13 @@ canonicalize_path(gchar *path) {
}
static void
-reset_file(NautilusFileInfo *file) {
+reset_file(CajaFileInfo *file) {
debug("resetting file %p", (void *) file);
- nautilus_file_info_invalidate_extension_info(file);
+ caja_file_info_invalidate_extension_info(file);
}
gboolean
-reset_all_files(NautilusDropbox *cvs) {
+reset_all_files(CajaDropbox *cvs) {
/* Only run this on the main loop or you'll cause problems. */
/* this works because you can call a function pointer with
@@ -116,7 +116,7 @@ reset_all_files(NautilusDropbox *cvs) {
static void
-when_file_dies(NautilusDropbox *cvs, NautilusFileInfo *address) {
+when_file_dies(CajaDropbox *cvs, CajaFileInfo *address) {
gchar *filename;
filename = g_hash_table_lookup(cvs->obj2filename, address);
@@ -134,14 +134,14 @@ when_file_dies(NautilusDropbox *cvs, NautilusFileInfo *address) {
}
static void
-changed_cb(NautilusFileInfo *file, NautilusDropbox *cvs) {
+changed_cb(CajaFileInfo *file, CajaDropbox *cvs) {
/* check if this file's path has changed, if so update the hash and invalidate
the file */
gchar *filename, *pfilename;
gchar *filename2;
gchar *uri;
- uri = nautilus_file_info_get_uri(file);
+ uri = caja_file_info_get_uri(file);
pfilename = g_filename_from_uri(uri, NULL, NULL);
filename = pfilename ? canonicalize_path(pfilename) : NULL;
filename2 = g_hash_table_lookup(cvs->obj2filename, file);
@@ -165,7 +165,7 @@ changed_cb(NautilusFileInfo *file, NautilusDropbox *cvs) {
return;
}
- /* this is a hack, because nautilus doesn't do this for us, for some reason
+ /* this is a hack, because caja doesn't do this for us, for some reason
the file's path has changed */
if (strcmp(filename, filename2) != 0) {
debug("shifty old: %s, new %s", filename2, filename);
@@ -176,7 +176,7 @@ changed_cb(NautilusFileInfo *file, NautilusDropbox *cvs) {
g_hash_table_replace(cvs->obj2filename, file, g_strdup(filename));
{
- NautilusFileInfo *f2;
+ CajaFileInfo *f2;
/* we shouldn't have another mapping from filename to an object */
f2 = g_hash_table_lookup(cvs->filename2obj, filename);
if (f2 != NULL) {
@@ -193,25 +193,25 @@ changed_cb(NautilusFileInfo *file, NautilusDropbox *cvs) {
g_free(filename);
}
-static NautilusOperationResult
-nautilus_dropbox_update_file_info(NautilusInfoProvider *provider,
- NautilusFileInfo *file,
+static CajaOperationResult
+caja_dropbox_update_file_info(CajaInfoProvider *provider,
+ CajaFileInfo *file,
GClosure *update_complete,
- NautilusOperationHandle **handle) {
- NautilusDropbox *cvs;
+ CajaOperationHandle **handle) {
+ CajaDropbox *cvs;
- cvs = NAUTILUS_DROPBOX(provider);
+ cvs = CAJA_DROPBOX(provider);
/* this code adds this file object to our two-way hash of file objects
so we can shell touch these files later */
{
gchar *pfilename, *uri;
- uri = nautilus_file_info_get_uri(file);
+ uri = caja_file_info_get_uri(file);
pfilename = g_filename_from_uri(uri, NULL, NULL);
g_free(uri);
if (pfilename == NULL) {
- return NAUTILUS_OPERATION_COMPLETE;
+ return CAJA_OPERATION_COMPLETE;
}
else {
int cmp = 0;
@@ -236,13 +236,13 @@ nautilus_dropbox_update_file_info(NautilusInfoProvider *provider,
g_signal_handlers_disconnect_by_func(file, G_CALLBACK(changed_cb), cvs);
}
else if (stored_filename == NULL) {
- NautilusFileInfo *f2;
+ CajaFileInfo *f2;
if ((f2 = g_hash_table_lookup(cvs->filename2obj, filename)) != NULL) {
/* if the filename exists in the filename2obj hash
but the file obj doesn't exist in the obj2filename hash:
- this happens when nautilus allocates another file object
+ this happens when caja allocates another file object
for a filename without first deleting the original file object
just remove the association to the older file object, it's obsolete
@@ -267,8 +267,8 @@ nautilus_dropbox_update_file_info(NautilusInfoProvider *provider,
}
if (dropbox_client_is_connected(&(cvs->dc)) == FALSE ||
- nautilus_file_info_is_gone(file)) {
- return NAUTILUS_OPERATION_COMPLETE;
+ caja_file_info_is_gone(file)) {
+ return CAJA_OPERATION_COMPLETE;
}
{
@@ -282,23 +282,23 @@ nautilus_dropbox_update_file_info(NautilusInfoProvider *provider,
dropbox_command_client_request(&(cvs->dc.dcc), (DropboxCommand *) dfic);
- *handle = (NautilusOperationHandle *) dfic;
+ *handle = (CajaOperationHandle *) dfic;
return dropbox_use_operation_in_progress_workaround
- ? NAUTILUS_OPERATION_COMPLETE
- : NAUTILUS_OPERATION_IN_PROGRESS;
+ ? CAJA_OPERATION_COMPLETE
+ : CAJA_OPERATION_IN_PROGRESS;
}
}
static void
-handle_shell_touch(GHashTable *args, NautilusDropbox *cvs) {
+handle_shell_touch(GHashTable *args, CajaDropbox *cvs) {
gchar **path;
// debug_enter();
if ((path = g_hash_table_lookup(args, "path")) != NULL &&
path[0][0] == '/') {
- NautilusFileInfo *file;
+ CajaFileInfo *file;
gchar *filename;
filename = canonicalize_path(path[0]);
@@ -318,16 +318,16 @@ handle_shell_touch(GHashTable *args, NautilusDropbox *cvs) {
}
gboolean
-nautilus_dropbox_finish_file_info_command(DropboxFileInfoCommandResponse *dficr) {
+caja_dropbox_finish_file_info_command(DropboxFileInfoCommandResponse *dficr) {
//debug_enter();
- NautilusOperationResult result = NAUTILUS_OPERATION_FAILED;
+ CajaOperationResult result = CAJA_OPERATION_FAILED;
if (!dficr->dfic->cancelled) {
gchar **status = NULL;
gboolean isdir;
- isdir = nautilus_file_info_is_directory(dficr->dfic->file) ;
+ isdir = caja_file_info_is_directory(dficr->dfic->file) ;
/* if we have emblems just use them. */
if (dficr->emblems_response != NULL &&
@@ -335,9 +335,9 @@ nautilus_dropbox_finish_file_info_command(DropboxFileInfoCommandResponse *dficr)
int i;
for ( i = 0; status[i] != NULL; i++) {
if (status[i][0])
- nautilus_file_info_add_emblem(dficr->dfic->file, status[i]);
+ caja_file_info_add_emblem(dficr->dfic->file, status[i]);
}
- result = NAUTILUS_OPERATION_COMPLETE;
+ result = CAJA_OPERATION_COMPLETE;
}
/* if the file status command went okay */
else if ((dficr->file_status_response != NULL &&
@@ -351,16 +351,16 @@ nautilus_dropbox_finish_file_info_command(DropboxFileInfoCommandResponse *dficr)
if (isdir &&
(tag = g_hash_table_lookup(dficr->folder_tag_response, "tag")) != NULL) {
if (strcmp("public", tag[0]) == 0) {
- nautilus_file_info_add_emblem(dficr->dfic->file, "web");
+ caja_file_info_add_emblem(dficr->dfic->file, "web");
}
else if (strcmp("shared", tag[0]) == 0) {
- nautilus_file_info_add_emblem(dficr->dfic->file, "people");
+ caja_file_info_add_emblem(dficr->dfic->file, "people");
}
else if (strcmp("photos", tag[0]) == 0) {
- nautilus_file_info_add_emblem(dficr->dfic->file, "photos");
+ caja_file_info_add_emblem(dficr->dfic->file, "photos");
}
else if (strcmp("sandbox", tag[0]) == 0) {
- nautilus_file_info_add_emblem(dficr->dfic->file, "star");
+ caja_file_info_add_emblem(dficr->dfic->file, "star");
}
}
@@ -381,21 +381,21 @@ nautilus_dropbox_finish_file_info_command(DropboxFileInfoCommandResponse *dficr)
if (emblem_code > 0) {
/*
debug("%s to %s", emblems[emblem_code-1],
- g_filename_from_uri(nautilus_file_info_get_uri(dficr->dfic->file),
+ g_filename_from_uri(caja_file_info_get_uri(dficr->dfic->file),
NULL, NULL));
*/
- nautilus_file_info_add_emblem(dficr->dfic->file, emblems[emblem_code-1]);
+ caja_file_info_add_emblem(dficr->dfic->file, emblems[emblem_code-1]);
}
}
- result = NAUTILUS_OPERATION_COMPLETE;
+ result = CAJA_OPERATION_COMPLETE;
}
}
/* complete the info request */
if (!dropbox_use_operation_in_progress_workaround) {
- nautilus_info_provider_update_complete_invoke(dficr->dfic->update_complete,
+ caja_info_provider_update_complete_invoke(dficr->dfic->update_complete,
dficr->dfic->provider,
- (NautilusOperationHandle*) dficr->dfic,
+ (CajaOperationHandle*) dficr->dfic,
result);
}
@@ -419,16 +419,16 @@ nautilus_dropbox_finish_file_info_command(DropboxFileInfoCommandResponse *dficr)
}
static void
-nautilus_dropbox_cancel_update(NautilusInfoProvider *provider,
- NautilusOperationHandle *handle) {
+caja_dropbox_cancel_update(CajaInfoProvider *provider,
+ CajaOperationHandle *handle) {
DropboxFileInfoCommand *dfic = (DropboxFileInfoCommand *) handle;
dfic->cancelled = TRUE;
return;
}
static void
-menu_item_cb(NautilusMenuItem *item,
- NautilusDropbox *cvs) {
+menu_item_cb(CajaMenuItem *item,
+ CajaDropbox *cvs) {
gchar *verb;
GList *files;
DropboxGeneralCommand *dcac;
@@ -438,8 +438,8 @@ menu_item_cb(NautilusMenuItem *item,
/* maybe these would be better passed in a container
struct used as the userdata pointer, oh well this
is how dave camp does it */
- files = g_object_get_data(G_OBJECT(item), "nautilus_dropbox_files");
- verb = g_object_get_data(G_OBJECT(item), "nautilus_dropbox_verb");
+ files = g_object_get_data(G_OBJECT(item), "caja_dropbox_files");
+ verb = g_object_get_data(G_OBJECT(item), "caja_dropbox_verb");
dcac->dc.request_type = GENERAL_COMMAND;
@@ -456,7 +456,7 @@ menu_item_cb(NautilusMenuItem *item,
arglist = g_new0(gchar *,g_list_length(files) + 1);
for (li = files, i = 0; li != NULL; li = g_list_next(li)) {
- char *uri = nautilus_file_info_get_uri(NAUTILUS_FILE_INFO(li->data));
+ char *uri = caja_file_info_get_uri(CAJA_FILE_INFO(li->data));
char *path = g_filename_from_uri(uri, NULL, NULL);
g_free(uri);
if (!path)
@@ -514,11 +514,11 @@ int GhettoURLDecode(gchar* out, gchar* in, int n) {
}
static int
-nautilus_dropbox_parse_menu(gchar **options,
- NautilusMenu *menu,
+caja_dropbox_parse_menu(gchar **options,
+ CajaMenu *menu,
GString *old_action_string,
GList *toret,
- NautilusMenuProvider *provider,
+ CajaMenuProvider *provider,
GList *files)
{
int ret = 0;
@@ -546,26 +546,26 @@ nautilus_dropbox_parse_menu(gchar **options,
if (strchr(item_inner, '~') != NULL) {
GString *new_action_string = g_string_new(old_action_string->str);
gchar **suboptions = g_strsplit(item_inner, "|", -1);
- NautilusMenuItem *item;
- NautilusMenu *submenu = nautilus_menu_new();
+ CajaMenuItem *item;
+ CajaMenu *submenu = caja_menu_new();
g_string_append(new_action_string, item_name);
g_string_append(new_action_string, "::");
- ret += nautilus_dropbox_parse_menu(suboptions, submenu, new_action_string,
+ ret += caja_dropbox_parse_menu(suboptions, submenu, new_action_string,
toret, provider, files);
- item = nautilus_menu_item_new(new_action_string->str,
+ item = caja_menu_item_new(new_action_string->str,
item_name, "", NULL);
- nautilus_menu_item_set_submenu(item, submenu);
- nautilus_menu_append_item(menu, item);
+ caja_menu_item_set_submenu(item, submenu);
+ caja_menu_append_item(menu, item);
g_strfreev(suboptions);
g_object_unref(item);
g_object_unref(submenu);
g_string_free(new_action_string, TRUE);
} else {
- NautilusMenuItem *item;
+ CajaMenuItem *item;
GString *new_action_string = g_string_new(old_action_string->str);
gboolean grayed_out = FALSE;
@@ -576,15 +576,15 @@ nautilus_dropbox_parse_menu(gchar **options,
grayed_out = TRUE;
}
- item = nautilus_menu_item_new(new_action_string->str, item_name, item_inner, NULL);
+ item = caja_menu_item_new(new_action_string->str, item_name, item_inner, NULL);
- nautilus_menu_append_item(menu, item);
+ caja_menu_append_item(menu, item);
/* add the file metadata to this item */
- g_object_set_data_full (G_OBJECT(item), "nautilus_dropbox_files",
- nautilus_file_info_list_copy (files),
- (GDestroyNotify) nautilus_file_info_list_free);
+ g_object_set_data_full (G_OBJECT(item), "caja_dropbox_files",
+ caja_file_info_list_copy (files),
+ (GDestroyNotify) caja_file_info_list_free);
/* add the verb metadata */
- g_object_set_data_full (G_OBJECT(item), "nautilus_dropbox_verb",
+ g_object_set_data_full (G_OBJECT(item), "caja_dropbox_verb",
g_strdup(verb),
(GDestroyNotify) g_free);
g_signal_connect (item, "activate", G_CALLBACK (menu_item_cb), provider);
@@ -596,10 +596,10 @@ nautilus_dropbox_parse_menu(gchar **options,
g_object_set_property (G_OBJECT(item), "sensitive", &sensitive);
}
- /* taken from nautilus-file-repairer (http://repairer.kldp.net/):
- * this code is a workaround for a bug of nautilus
+ /* taken from caja-file-repairer (http://repairer.kldp.net/):
+ * this code is a workaround for a bug of caja
* See: http://bugzilla.gnome.org/show_bug.cgi?id=508878 */
- if (dropbox_use_nautilus_submenu_workaround) {
+ if (dropbox_use_caja_submenu_workaround) {
toret = g_list_append(toret, item);
}
@@ -626,7 +626,7 @@ get_file_items_callback(GHashTable *response, gpointer ud)
static GList *
-nautilus_dropbox_get_file_items(NautilusMenuProvider *provider,
+caja_dropbox_get_file_items(CajaMenuProvider *provider,
GtkWidget *window,
GList *files)
{
@@ -643,7 +643,7 @@ nautilus_dropbox_get_file_items(NautilusMenuProvider *provider,
GList* elem;
for (elem = files; elem; elem = elem->next, i++) {
- gchar *uri = nautilus_file_info_get_uri(elem->data);
+ gchar *uri = caja_file_info_get_uri(elem->data);
gchar *filename_un = uri ? g_filename_from_uri(uri, NULL, NULL) : NULL;
gchar *filename = filename_un ? g_filename_to_utf8(filename_un, -1, NULL, NULL, NULL) : NULL;
@@ -679,13 +679,13 @@ nautilus_dropbox_get_file_items(NautilusMenuProvider *provider,
/*
* 3. Queue it up for the helper thread to run it.
*/
- NautilusDropbox *cvs = NAUTILUS_DROPBOX(provider);
+ CajaDropbox *cvs = CAJA_DROPBOX(provider);
dropbox_command_client_request(&(cvs->dc.dcc), (DropboxCommand *) dgc);
GTimeVal gtv;
/*
- * 4. We have to block until it's done because nautilus expects a reply. But we will
+ * 4. We have to block until it's done because caja expects a reply. But we will
* only block for 50 ms for a reply.
*/
@@ -708,23 +708,23 @@ nautilus_dropbox_get_file_items(NautilusMenuProvider *provider,
if (options && *options && **options) {
/* build the menu */
- NautilusMenuItem *root_item;
- NautilusMenu *root_menu;
+ CajaMenuItem *root_item;
+ CajaMenu *root_menu;
- root_menu = nautilus_menu_new();
- root_item = nautilus_menu_item_new("NautilusDropbox::root_item",
+ root_menu = caja_menu_new();
+ root_item = caja_menu_item_new("CajaDropbox::root_item",
"Dropbox", "Dropbox Options", "dropbox");
toret = g_list_append(toret, root_item);
- GString *action_string = g_string_new("NautilusDropbox::");
+ GString *action_string = g_string_new("CajaDropbox::");
- if (!nautilus_dropbox_parse_menu(options, root_menu, action_string,
+ if (!caja_dropbox_parse_menu(options, root_menu, action_string,
toret, provider, files)) {
g_object_unref(toret);
toret = NULL;
}
- nautilus_menu_item_set_submenu(root_item, root_menu);
+ caja_menu_item_set_submenu(root_item, root_menu);
g_string_free(action_string, TRUE);
g_object_unref(root_menu);
@@ -809,7 +809,7 @@ exit:
return FALSE;
}
-void get_emblem_paths_cb(GHashTable *emblem_paths_response, NautilusDropbox *cvs)
+void get_emblem_paths_cb(GHashTable *emblem_paths_response, CajaDropbox *cvs)
{
if (!emblem_paths_response) {
emblem_paths_response = g_hash_table_new((GHashFunc) g_str_hash,
@@ -833,16 +833,16 @@ void get_emblem_paths_cb(GHashTable *emblem_paths_response, NautilusDropbox *cvs
}
static void
-on_connect(NautilusDropbox *cvs) {
+on_connect(CajaDropbox *cvs) {
reset_all_files(cvs);
dropbox_command_client_send_command(&(cvs->dc.dcc),
- (NautilusDropboxCommandResponseHandler) get_emblem_paths_cb,
+ (CajaDropboxCommandResponseHandler) get_emblem_paths_cb,
cvs, "get_emblem_paths", NULL);
}
static void
-on_disconnect(NautilusDropbox *cvs) {
+on_disconnect(CajaDropbox *cvs) {
reset_all_files(cvs);
g_mutex_lock(cvs->emblem_paths_mutex);
@@ -854,20 +854,20 @@ on_disconnect(NautilusDropbox *cvs) {
static void
-nautilus_dropbox_menu_provider_iface_init (NautilusMenuProviderIface *iface) {
- iface->get_file_items = nautilus_dropbox_get_file_items;
+caja_dropbox_menu_provider_iface_init (CajaMenuProviderIface *iface) {
+ iface->get_file_items = caja_dropbox_get_file_items;
return;
}
static void
-nautilus_dropbox_info_provider_iface_init (NautilusInfoProviderIface *iface) {
- iface->update_file_info = nautilus_dropbox_update_file_info;
- iface->cancel_update = nautilus_dropbox_cancel_update;
+caja_dropbox_info_provider_iface_init (CajaInfoProviderIface *iface) {
+ iface->update_file_info = caja_dropbox_update_file_info;
+ iface->cancel_update = caja_dropbox_cancel_update;
return;
}
static void
-nautilus_dropbox_instance_init (NautilusDropbox *cvs) {
+caja_dropbox_instance_init (CajaDropbox *cvs) {
cvs->filename2obj = g_hash_table_new_full((GHashFunc) g_str_hash,
(GEqualFunc) g_str_equal,
(GDestroyNotify) g_free,
@@ -883,7 +883,7 @@ nautilus_dropbox_instance_init (NautilusDropbox *cvs) {
dropbox_client_setup(&(cvs->dc));
/* our hooks */
- nautilus_dropbox_hooks_add(&(cvs->dc.hookserv), "shell_touch",
+ caja_dropbox_hooks_add(&(cvs->dc.hookserv), "shell_touch",
(DropboxUpdateHook) handle_shell_touch, cvs);
/* add connection handlers */
@@ -902,42 +902,42 @@ nautilus_dropbox_instance_init (NautilusDropbox *cvs) {
}
static void
-nautilus_dropbox_class_init (NautilusDropboxClass *class) {
+caja_dropbox_class_init (CajaDropboxClass *class) {
}
static void
-nautilus_dropbox_class_finalize (NautilusDropboxClass *class) {
+caja_dropbox_class_finalize (CajaDropboxClass *class) {
debug("just checking");
/* kill threads here? */
}
GType
-nautilus_dropbox_get_type (void) {
+caja_dropbox_get_type (void) {
return dropbox_type;
}
void
-nautilus_dropbox_register_type (GTypeModule *module) {
+caja_dropbox_register_type (GTypeModule *module) {
static const GTypeInfo info = {
- sizeof (NautilusDropboxClass),
+ sizeof (CajaDropboxClass),
(GBaseInitFunc) NULL,
(GBaseFinalizeFunc) NULL,
- (GClassInitFunc) nautilus_dropbox_class_init,
- (GClassFinalizeFunc) nautilus_dropbox_class_finalize,
+ (GClassInitFunc) caja_dropbox_class_init,
+ (GClassFinalizeFunc) caja_dropbox_class_finalize,
NULL,
- sizeof (NautilusDropbox),
+ sizeof (CajaDropbox),
0,
- (GInstanceInitFunc) nautilus_dropbox_instance_init,
+ (GInstanceInitFunc) caja_dropbox_instance_init,
};
static const GInterfaceInfo menu_provider_iface_info = {
- (GInterfaceInitFunc) nautilus_dropbox_menu_provider_iface_init,
+ (GInterfaceInitFunc) caja_dropbox_menu_provider_iface_init,
NULL,
NULL
};
static const GInterfaceInfo info_provider_iface_info = {
- (GInterfaceInitFunc) nautilus_dropbox_info_provider_iface_init,
+ (GInterfaceInitFunc) caja_dropbox_info_provider_iface_init,
NULL,
NULL
};
@@ -945,16 +945,16 @@ nautilus_dropbox_register_type (GTypeModule *module) {
dropbox_type =
g_type_module_register_type(module,
G_TYPE_OBJECT,
- "NautilusDropbox",
+ "CajaDropbox",
&info, 0);
g_type_module_add_interface (module,
dropbox_type,
- NAUTILUS_TYPE_MENU_PROVIDER,
+ CAJA_TYPE_MENU_PROVIDER,
&menu_provider_iface_info);
g_type_module_add_interface (module,
dropbox_type,
- NAUTILUS_TYPE_INFO_PROVIDER,
+ CAJA_TYPE_INFO_PROVIDER,
&info_provider_iface_info);
}
diff --git a/src/caja-dropbox.h b/src/caja-dropbox.h
new file mode 100644
index 0000000..b0b3c59
--- /dev/null
+++ b/src/caja-dropbox.h
@@ -0,0 +1,69 @@
+/*
+ * Copyright 2008 Evenflow, Inc.
+ *
+ * caja-dropbox.h
+ * Header file for caja-dropbox.c
+ *
+ * This file is part of caja-dropbox.
+ *
+ * caja-dropbox is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * caja-dropbox is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with caja-dropbox. If not, see <http://www.gnu.org/licenses/>.
+ *
+ */
+
+#ifndef CAJA_DROPBOX_H
+#define CAJA_DROPBOX_H
+
+#include <glib.h>
+#include <glib-object.h>
+
+#include <libcaja-extension/caja-info-provider.h>
+
+#include "dropbox-command-client.h"
+#include "caja-dropbox-hooks.h"
+#include "dropbox-client.h"
+
+G_BEGIN_DECLS
+
+/* Declarations for the dropbox extension object. This object will be
+ * instantiated by caja. It implements the GInterfaces
+ * exported by libcaja. */
+
+#define CAJA_TYPE_DROPBOX (caja_dropbox_get_type ())
+#define CAJA_DROPBOX(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CAJA_TYPE_DROPBOX, CajaDropbox))
+#define CAJA_IS_DROPBOX(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CAJA_TYPE_DROPBOX))
+typedef struct _CajaDropbox CajaDropbox;
+typedef struct _CajaDropboxClass CajaDropboxClass;
+
+struct _CajaDropbox {
+ GObject parent_slot;
+ GHashTable *filename2obj;
+ GHashTable *obj2filename;
+ GMutex *emblem_paths_mutex;
+ GHashTable *emblem_paths;
+ DropboxClient dc;
+};
+
+struct _CajaDropboxClass {
+ GObjectClass parent_slot;
+};
+
+GType caja_dropbox_get_type(void);
+void caja_dropbox_register_type(GTypeModule *module);
+
+extern gboolean dropbox_use_caja_submenu_workaround;
+extern gboolean dropbox_use_operation_in_progress_workaround;
+
+G_END_DECLS
+
+#endif
diff --git a/src/dropbox-client-util.c b/src/dropbox-client-util.c
index 2351c81..8419957 100644
--- a/src/dropbox-client-util.c
+++ b/src/dropbox-client-util.c
@@ -4,20 +4,20 @@
* dropbox-client-util.c
* Utility functions for implementing dropbox clients.
*
- * This file is part of nautilus-dropbox.
+ * This file is part of caja-dropbox.
*
- * nautilus-dropbox is free software: you can redistribute it and/or modify
+ * caja-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
- * nautilus-dropbox is distributed in the hope that it will be useful,
+ * caja-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with nautilus-dropbox. If not, see <http://www.gnu.org/licenses/>.
+ * along with caja-dropbox. If not, see <http://www.gnu.org/licenses/>.
*
*/
diff --git a/src/dropbox-client-util.h b/src/dropbox-client-util.h
index 7813a3f..4f44530 100644
--- a/src/dropbox-client-util.h
+++ b/src/dropbox-client-util.h
@@ -4,20 +4,20 @@
* dropbox-client-util.h
* Header file for dropbox-client-util.c
*
- * This file is part of nautilus-dropbox.
+ * This file is part of caja-dropbox.
*
- * nautilus-dropbox is free software: you can redistribute it and/or modify
+ * caja-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
- * nautilus-dropbox is distributed in the hope that it will be useful,
+ * caja-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with nautilus-dropbox. If not, see <http://www.gnu.org/licenses/>.
+ * along with caja-dropbox. If not, see <http://www.gnu.org/licenses/>.
*
*/
diff --git a/src/g-util.h b/src/g-util.h
index 73d3d81..671a6ca 100644
--- a/src/g-util.h
+++ b/src/g-util.h
@@ -4,20 +4,20 @@
* g-util.h
* Helper macros.
*
- * This file is part of nautilus-dropbox.
+ * This file is part of caja-dropbox.
*
- * nautilus-dropbox is free software: you can redistribute it and/or modify
+ * caja-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
- * nautilus-dropbox is distributed in the hope that it will be useful,
+ * caja-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with nautilus-dropbox. If not, see <http://www.gnu.org/licenses/>.
+ * along with caja-dropbox. If not, see <http://www.gnu.org/licenses/>.
*
*/
diff --git a/src/nautilus-dropbox.h b/src/nautilus-dropbox.h
deleted file mode 100644
index 65734be..0000000
--- a/src/nautilus-dropbox.h
+++ /dev/null
@@ -1,69 +0,0 @@
-/*
- * Copyright 2008 Evenflow, Inc.
- *
- * nautilus-dropbox.h
- * Header file for nautilus-dropbox.c
- *
- * This file is part of nautilus-dropbox.
- *
- * nautilus-dropbox is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * nautilus-dropbox is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with nautilus-dropbox. If not, see <http://www.gnu.org/licenses/>.
- *
- */
-
-#ifndef NAUTILUS_DROPBOX_H
-#define NAUTILUS_DROPBOX_H
-
-#include <glib.h>
-#include <glib-object.h>
-
-#include <libnautilus-extension/nautilus-info-provider.h>
-
-#include "dropbox-command-client.h"
-#include "nautilus-dropbox-hooks.h"
-#include "dropbox-client.h"
-
-G_BEGIN_DECLS
-
-/* Declarations for the dropbox extension object. This object will be
- * instantiated by nautilus. It implements the GInterfaces
- * exported by libnautilus. */
-
-#define NAUTILUS_TYPE_DROPBOX (nautilus_dropbox_get_type ())
-#define NAUTILUS_DROPBOX(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), NAUTILUS_TYPE_DROPBOX, NautilusDropbox))
-#define NAUTILUS_IS_DROPBOX(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), NAUTILUS_TYPE_DROPBOX))
-typedef struct _NautilusDropbox NautilusDropbox;
-typedef struct _NautilusDropboxClass NautilusDropboxClass;
-
-struct _NautilusDropbox {
- GObject parent_slot;
- GHashTable *filename2obj;
- GHashTable *obj2filename;
- GMutex *emblem_paths_mutex;
- GHashTable *emblem_paths;
- DropboxClient dc;
-};
-
-struct _NautilusDropboxClass {
- GObjectClass parent_slot;
-};
-
-GType nautilus_dropbox_get_type(void);
-void nautilus_dropbox_register_type(GTypeModule *module);
-
-extern gboolean dropbox_use_nautilus_submenu_workaround;
-extern gboolean dropbox_use_operation_in_progress_workaround;
-
-G_END_DECLS
-
-#endif
diff --git a/src/nautilus-dropbox-hooks.c b/src/caja-dropbox-hooks.c
index f37dbbb..86cb07d 100644
--- a/src/nautilus-dropbox-hooks.c
+++ b/src/caja-dropbox-hooks.c
@@ -1,23 +1,23 @@
/*
* Copyright 2008 Evenflow, Inc.
*
- * nautilus-dropbox-hooks.c
+ * caja-dropbox-hooks.c
* Implements connection handling and C interface for the Dropbox hook socket.
*
* This file is part of nautilus-dropbox.
*
* nautilus-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* nautilus-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with nautilus-dropbox. If not, see <http://www.gnu.org/licenses/>.
+ * along with caja-dropbox. If not, see <http://www.gnu.org/licenses/>.
*
*/
@@ -35,7 +35,7 @@
#include "g-util.h"
#include "async-io-coroutine.h"
#include "dropbox-client-util.h"
-#include "nautilus-dropbox-hooks.h"
+#include "caja-dropbox-hooks.h"
typedef struct {
DropboxUpdateHook hook;
@@ -43,12 +43,12 @@ typedef struct {
} HookData;
static gboolean
-try_to_connect(NautilusDropboxHookserv *hookserv);
+try_to_connect(CajaDropboxHookserv *hookserv);
static gboolean
handle_hook_server_input(GIOChannel *chan,
GIOCondition cond,
- NautilusDropboxHookserv *hookserv) {
+ CajaDropboxHookserv *hookserv) {
/*debug_enter(); */
/* we have some sweet macros defined that allow us to write this
@@ -123,7 +123,7 @@ handle_hook_server_input(GIOChannel *chan,
}
static void
-watch_killer(NautilusDropboxHookserv *hookserv) {
+watch_killer(CajaDropboxHookserv *hookserv) {
debug("hook client disconnected");
hookserv->connected = FALSE;
@@ -152,7 +152,7 @@ watch_killer(NautilusDropboxHookserv *hookserv) {
}
static gboolean
-try_to_connect(NautilusDropboxHookserv *hookserv) {
+try_to_connect(CajaDropboxHookserv *hookserv) {
/* create socket */
hookserv->socket = socket(PF_UNIX, SOCK_STREAM, 0);
@@ -258,7 +258,7 @@ try_to_connect(NautilusDropboxHookserv *hookserv) {
/* should only be called in glib main loop */
/* returns a gboolean because it is a GSourceFunc */
-gboolean nautilus_dropbox_hooks_force_reconnect(NautilusDropboxHookserv *hookserv) {
+gboolean caja_dropbox_hooks_force_reconnect(CajaDropboxHookserv *hookserv) {
debug_enter();
if (hookserv->connected == FALSE) {
@@ -280,12 +280,12 @@ gboolean nautilus_dropbox_hooks_force_reconnect(NautilusDropboxHookserv *hookser
}
gboolean
-nautilus_dropbox_hooks_is_connected(NautilusDropboxHookserv *hookserv) {
+caja_dropbox_hooks_is_connected(CajaDropboxHookserv *hookserv) {
return hookserv->connected;
}
void
-nautilus_dropbox_hooks_setup(NautilusDropboxHookserv *hookserv) {
+caja_dropbox_hooks_setup(CajaDropboxHookserv *hookserv) {
hookserv->dispatch_table = g_hash_table_new_full((GHashFunc) g_str_hash,
(GEqualFunc) g_str_equal,
g_free, g_free);
@@ -296,7 +296,7 @@ nautilus_dropbox_hooks_setup(NautilusDropboxHookserv *hookserv) {
}
void
-nautilus_dropbox_hooks_add_on_disconnect_hook(NautilusDropboxHookserv *hookserv,
+caja_dropbox_hooks_add_on_disconnect_hook(CajaDropboxHookserv *hookserv,
DropboxHookClientConnectHook dhcch,
gpointer ud) {
GHook *newhook;
@@ -309,7 +309,7 @@ nautilus_dropbox_hooks_add_on_disconnect_hook(NautilusDropboxHookserv *hookserv,
}
void
-nautilus_dropbox_hooks_add_on_connect_hook(NautilusDropboxHookserv *hookserv,
+caja_dropbox_hooks_add_on_connect_hook(CajaDropboxHookserv *hookserv,
DropboxHookClientConnectHook dhcch,
gpointer ud) {
GHook *newhook;
@@ -321,7 +321,7 @@ nautilus_dropbox_hooks_add_on_connect_hook(NautilusDropboxHookserv *hookserv,
g_hook_append(&(hookserv->onconnect_hooklist), newhook);
}
-void nautilus_dropbox_hooks_add(NautilusDropboxHookserv *ndhs,
+void caja_dropbox_hooks_add(CajaDropboxHookserv *ndhs,
const gchar *hook_name,
DropboxUpdateHook hook, gpointer ud) {
HookData *hd;
@@ -332,6 +332,6 @@ void nautilus_dropbox_hooks_add(NautilusDropboxHookserv *ndhs,
}
void
-nautilus_dropbox_hooks_start(NautilusDropboxHookserv *hookserv) {
+caja_dropbox_hooks_start(CajaDropboxHookserv *hookserv) {
try_to_connect(hookserv);
}
@@ -1,23 +1,23 @@
* Implements connection handling and C interface for the Dropbox hook socket.
*
- * This file is part of nautilus-dropbox.
+ * This file is part of caja-dropbox.
*
@@ -1,23 +1,23 @@
*
- * nautilus-dropbox is free software: you can redistribute it and/or modify
+ * caja-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
@@ -1,23 +1,23 @@
* (at your option) any later version.
*
- * nautilus-dropbox is distributed in the hope that it will be useful,
+ * caja-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/src/nautilus-dropbox-hooks.h b/src/caja-dropbox-hooks.h
index fb69c3b..7e5c2a9 100644
--- a/src/nautilus-dropbox-hooks.h
+++ b/src/caja-dropbox-hooks.h
@@ -1,28 +1,28 @@
/*
* Copyright 2008 Evenflow, Inc.
*
* nautilus-dropbox-hooks.h
* Header file for nautilus-dropbox-hooks.c
*
* This file is part of nautilus-dropbox.
*
* nautilus-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* nautilus-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with nautilus-dropbox. If not, see <http://www.gnu.org/licenses/>.
+ * along with caja-dropbox. If not, see <http://www.gnu.org/licenses/>.
*
*/
-#ifndef NAUTILUS_DROPBOX_HOOKS_H
-#define NAUTILUS_DROPBOX_HOOKS_H
+#ifndef CAJA_DROPBOX_HOOKS_H
+#define CAJA_DROPBOX_HOOKS_H
#include <glib.h>
@@ -45,31 +45,31 @@ typedef struct {
GHashTable *dispatch_table;
GHookList ondisconnect_hooklist;
GHookList onconnect_hooklist;
-} NautilusDropboxHookserv;
+} CajaDropboxHookserv;
void
-nautilus_dropbox_hooks_setup(NautilusDropboxHookserv *);
+caja_dropbox_hooks_setup(CajaDropboxHookserv *);
void
-nautilus_dropbox_hooks_start(NautilusDropboxHookserv *);
+caja_dropbox_hooks_start(CajaDropboxHookserv *);
gboolean
-nautilus_dropbox_hooks_is_connected(NautilusDropboxHookserv *);
+caja_dropbox_hooks_is_connected(CajaDropboxHookserv *);
gboolean
-nautilus_dropbox_hooks_force_reconnect(NautilusDropboxHookserv *);
+caja_dropbox_hooks_force_reconnect(CajaDropboxHookserv *);
void
-nautilus_dropbox_hooks_add(NautilusDropboxHookserv *ndhs,
+caja_dropbox_hooks_add(CajaDropboxHookserv *ndhs,
const gchar *hook_name,
DropboxUpdateHook hook, gpointer ud);
void
-nautilus_dropbox_hooks_add_on_disconnect_hook(NautilusDropboxHookserv *hookserv,
+caja_dropbox_hooks_add_on_disconnect_hook(CajaDropboxHookserv *hookserv,
DropboxHookClientConnectHook dhcch,
gpointer ud);
void
-nautilus_dropbox_hooks_add_on_connect_hook(NautilusDropboxHookserv *hookserv,
+caja_dropbox_hooks_add_on_connect_hook(CajaDropboxHookserv *hookserv,
DropboxHookClientConnectHook dhcch,
gpointer ud);
@@ -1,28 +1,28 @@
* Copyright 2008 Evenflow, Inc.
*
- * nautilus-dropbox-hooks.h
- * Header file for nautilus-dropbox-hooks.c
+ * caja-dropbox-hooks.h
+ * Header file for caja-dropbox-hooks.c
*
@@ -1,28 +1,28 @@
*
- * This file is part of nautilus-dropbox.
+ * This file is part of caja-dropbox.
*
@@ -1,28 +1,28 @@
*
- * nautilus-dropbox is free software: you can redistribute it and/or modify
+ * caja-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
@@ -1,28 +1,28 @@
* (at your option) any later version.
*
- * nautilus-dropbox is distributed in the hope that it will be useful,
+ * caja-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/src/dropbox-client.c b/src/dropbox-client.c
index dbd4f77..8563197 100644
--- a/src/dropbox-client.c
+++ b/src/dropbox-client.c
@@ -4,20 +4,20 @@
* dropbox-client.c
* Implements connection handling and C interface for interfacing with the Dropbox daemon.
*
* This file is part of nautilus-dropbox.
*
* nautilus-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* nautilus-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with nautilus-dropbox. If not, see <http://www.gnu.org/licenses/>.
+ * along with caja-dropbox. If not, see <http://www.gnu.org/licenses/>.
*
*/
@@ -25,7 +25,7 @@
#include "g-util.h"
#include "dropbox-command-client.h"
-#include "nautilus-dropbox-hooks.h"
+#include "caja-dropbox-hooks.h"
#include "dropbox-client.h"
static void
@@ -63,7 +63,7 @@ command_on_disconnect(DropboxClient *dc) {
dc->hook_disconnect_called = dc->command_disconnect_called = FALSE;
}
else {
- nautilus_dropbox_hooks_force_reconnect(&(dc->hookserv));
+ caja_dropbox_hooks_force_reconnect(&(dc->hookserv));
}
}
@@ -85,7 +85,7 @@ hook_on_disconnect(DropboxClient *dc) {
gboolean
dropbox_client_is_connected(DropboxClient *dc) {
return (dropbox_command_client_is_connected(&(dc->dcc)) &&
- nautilus_dropbox_hooks_is_connected(&(dc->hookserv)));
+ caja_dropbox_hooks_is_connected(&(dc->hookserv)));
}
void
@@ -93,14 +93,14 @@ dropbox_client_force_reconnect(DropboxClient *dc) {
if (dropbox_client_is_connected(dc) == TRUE) {
debug("forcing client to reconnect");
dropbox_command_client_force_reconnect(&(dc->dcc));
- nautilus_dropbox_hooks_force_reconnect(&(dc->hookserv));
+ caja_dropbox_hooks_force_reconnect(&(dc->hookserv));
}
}
/* should only be called once on initialization */
void
dropbox_client_setup(DropboxClient *dc) {
- nautilus_dropbox_hooks_setup(&(dc->hookserv));
+ caja_dropbox_hooks_setup(&(dc->hookserv));
dropbox_command_client_setup(&(dc->dcc));
g_hook_list_init(&(dc->ondisconnect_hooklist), sizeof(GHook));
@@ -109,7 +109,7 @@ dropbox_client_setup(DropboxClient *dc) {
dc->hook_disconnect_called = dc->command_disconnect_called = FALSE;
dc->hook_connect_called = dc->command_connect_called = FALSE;
- nautilus_dropbox_hooks_add_on_connect_hook(&(dc->hookserv),
+ caja_dropbox_hooks_add_on_connect_hook(&(dc->hookserv),
(DropboxHookClientConnectHook)
hook_on_connect, dc);
@@ -117,7 +117,7 @@ dropbox_client_setup(DropboxClient *dc) {
(DropboxCommandClientConnectHook)
command_on_connect, dc);
- nautilus_dropbox_hooks_add_on_disconnect_hook(&(dc->hookserv),
+ caja_dropbox_hooks_add_on_disconnect_hook(&(dc->hookserv),
(DropboxHookClientConnectHook)
hook_on_disconnect, dc);
@@ -169,6 +169,6 @@ dropbox_client_add_connection_attempt_hook(DropboxClient *dc,
void
dropbox_client_start(DropboxClient *dc) {
debug("starting connections");
- nautilus_dropbox_hooks_start(&(dc->hookserv));
+ caja_dropbox_hooks_start(&(dc->hookserv));
dropbox_command_client_start(&(dc->dcc));
}
@@ -4,20 +4,20 @@
* Implements connection handling and C interface for interfacing with the Dropbox daemon.
*
- * This file is part of nautilus-dropbox.
+ * This file is part of caja-dropbox.
*
@@ -4,20 +4,20 @@
*
- * nautilus-dropbox is free software: you can redistribute it and/or modify
+ * caja-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
@@ -4,20 +4,20 @@
* (at your option) any later version.
*
- * nautilus-dropbox is distributed in the hope that it will be useful,
+ * caja-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/src/dropbox-client.h b/src/dropbox-client.h
index c981c44..29c7eb4 100644
--- a/src/dropbox-client.h
+++ b/src/dropbox-client.h
@@ -4,20 +4,20 @@
* dropbox-client.h
* Header file for dropbox-client.c
*
* This file is part of nautilus-dropbox.
*
* nautilus-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* nautilus-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with nautilus-dropbox. If not, see <http://www.gnu.org/licenses/>.
+ * along with caja-dropbox. If not, see <http://www.gnu.org/licenses/>.
*
*/
@@ -26,13 +26,13 @@
#include <glib.h>
#include "dropbox-command-client.h"
-#include "nautilus-dropbox-hooks.h"
+#include "caja-dropbox-hooks.h"
G_BEGIN_DECLS
typedef struct {
DropboxCommandClient dcc;
- NautilusDropboxHookserv hookserv;
+ CajaDropboxHookserv hookserv;
GHookList onconnect_hooklist;
GHookList ondisconnect_hooklist;
gboolean hook_connect_called;
@@ -4,20 +4,20 @@
* Header file for dropbox-client.c
*
- * This file is part of nautilus-dropbox.
+ * This file is part of caja-dropbox.
*
@@ -4,20 +4,20 @@
*
- * nautilus-dropbox is free software: you can redistribute it and/or modify
+ * caja-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
@@ -4,20 +4,20 @@
* (at your option) any later version.
*
- * nautilus-dropbox is distributed in the hope that it will be useful,
+ * caja-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/src/dropbox-command-client.c b/src/dropbox-command-client.c
index bdec125..dd02fd0 100644
--- a/src/dropbox-command-client.c
+++ b/src/dropbox-command-client.c
@@ -4,20 +4,20 @@
* dropbox-command-client.c
* Implements connection handling and C interface for the Dropbox command socket.
*
* This file is part of nautilus-dropbox.
*
* nautilus-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* nautilus-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with nautilus-dropbox. If not, see <http://www.gnu.org/licenses/>.
+ * along with caja-dropbox. If not, see <http://www.gnu.org/licenses/>.
*
*/
@@ -36,18 +36,18 @@
#include "g-util.h"
#include "dropbox-client-util.h"
#include "dropbox-command-client.h"
-#include "nautilus-dropbox.h"
-#include "nautilus-dropbox-hooks.h"
+#include "caja-dropbox.h"
+#include "caja-dropbox-hooks.h"
/* TODO: make this asynchronous ;) */
/*
this is a tiny hack, necessitated by the fact that
- finish_file info command is in nautilus_dropbox,
+ finish_file info command is in caja_dropbox,
this can be cleaned up once the file_info_command isn't a special
case anylonger
*/
-gboolean nautilus_dropbox_finish_file_info_command(DropboxFileInfoCommandResponse *);
+gboolean caja_dropbox_finish_file_info_command(DropboxFileInfoCommandResponse *);
typedef struct {
DropboxCommandClient *dcc;
@@ -351,7 +351,7 @@ do_file_info_command(GIOChannel *chan, DropboxFileInfoCommand *dfic, GError **ge
{
gchar *filename_un, *uri;
- uri = nautilus_file_info_get_uri(dfic->file);
+ uri = caja_file_info_get_uri(dfic->file);
filename_un = uri ? g_filename_from_uri(uri, NULL, NULL): NULL;
g_free(uri);
if (filename_un) {
@@ -400,7 +400,7 @@ do_file_info_command(GIOChannel *chan, DropboxFileInfoCommand *dfic, GError **ge
return;
}
- if (nautilus_file_info_is_directory(dfic->file)) {
+ if (caja_file_info_is_directory(dfic->file)) {
args = g_hash_table_new_full((GHashFunc) g_str_hash,
(GEqualFunc) g_str_equal,
(GDestroyNotify) g_free,
@@ -435,7 +435,7 @@ exit:
dficr->folder_tag_response = folder_tag_response;
dficr->file_status_response = file_status_response;
dficr->emblems_response = emblems_response;
- g_idle_add((GSourceFunc) nautilus_dropbox_finish_file_info_command, dficr);
+ g_idle_add((GSourceFunc) caja_dropbox_finish_file_info_command, dficr);
g_free(filename);
@@ -532,7 +532,7 @@ end_request(DropboxCommand *dc) {
dficr->dfic = dfic;
dficr->file_status_response = NULL;
dficr->emblems_response = NULL;
- g_idle_add((GSourceFunc) nautilus_dropbox_finish_file_info_command, dficr);
+ g_idle_add((GSourceFunc) caja_dropbox_finish_file_info_command, dficr);
}
break;
case GENERAL_COMMAND: {
@@ -678,7 +678,7 @@ dropbox_command_client_thread(DropboxCommandClient *dcc) {
g_get_current_time(&gtv);
g_time_val_add(&gtv, G_USEC_PER_SEC / 10);
/* get a request from nautilus */
dc = g_async_queue_timed_pop(dcc->command_queue, &gtv);
if (dc != NULL) {
break;
@@ -854,7 +854,7 @@ void dropbox_command_client_send_simple_command(DropboxCommandClient *dcc,
/* this is the C API, there is another send_command_to_db
that is more the actual over the wire command */
void dropbox_command_client_send_command(DropboxCommandClient *dcc,
- NautilusDropboxCommandResponseHandler h,
+ CajaDropboxCommandResponseHandler h,
gpointer ud,
const char *command, ...) {
va_list ap;
@@ -4,20 +4,20 @@
* Implements connection handling and C interface for the Dropbox command socket.
*
- * This file is part of nautilus-dropbox.
+ * This file is part of caja-dropbox.
*
@@ -4,20 +4,20 @@
*
- * nautilus-dropbox is free software: you can redistribute it and/or modify
+ * caja-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
@@ -4,20 +4,20 @@
* (at your option) any later version.
*
- * nautilus-dropbox is distributed in the hope that it will be useful,
+ * caja-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -678,7 +678,7 @@ dropbox_command_client_thread(DropboxCommandClient *dcc) {
g_get_current_time(&gtv);
g_time_val_add(&gtv, G_USEC_PER_SEC / 10);
- /* get a request from nautilus */
+ /* get a request from caja */
dc = g_async_queue_timed_pop(dcc->command_queue, &gtv);
if (dc != NULL) {
diff --git a/src/dropbox-command-client.h b/src/dropbox-command-client.h
index c1ea3bc..a06f777 100644
--- a/src/dropbox-command-client.h
+++ b/src/dropbox-command-client.h
@@ -2,45 +2,45 @@
* Copyright 2008 Evenflow, Inc.
*
* dropbox-command-client.h
* Header file for nautilus-dropbox-command.c
*
* This file is part of nautilus-dropbox.
*
* nautilus-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* nautilus-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with nautilus-dropbox. If not, see <http://www.gnu.org/licenses/>.
+ * along with caja-dropbox. If not, see <http://www.gnu.org/licenses/>.
*
*/
#ifndef DROPBOX_COMMAND_CLIENT_H
#define DROPBOX_COMMAND_CLIENT_H
-#include <libnautilus-extension/nautilus-info-provider.h>
-#include <libnautilus-extension/nautilus-file-info.h>
+#include <libcaja-extension/caja-info-provider.h>
+#include <libcaja-extension/caja-file-info.h>
G_BEGIN_DECLS
/* command structs */
-typedef enum {GET_FILE_INFO, GENERAL_COMMAND} NautilusDropboxRequestType;
+typedef enum {GET_FILE_INFO, GENERAL_COMMAND} CajaDropboxRequestType;
typedef struct {
- NautilusDropboxRequestType request_type;
+ CajaDropboxRequestType request_type;
} DropboxCommand;
typedef struct {
DropboxCommand dc;
- NautilusInfoProvider *provider;
+ CajaInfoProvider *provider;
GClosure *update_complete;
- NautilusFileInfo *file;
+ CajaFileInfo *file;
gboolean cancelled;
} DropboxFileInfoCommand;
@@ -51,13 +51,13 @@ typedef struct {
GHashTable *emblems_response;
} DropboxFileInfoCommandResponse;
-typedef void (*NautilusDropboxCommandResponseHandler)(GHashTable *, gpointer);
+typedef void (*CajaDropboxCommandResponseHandler)(GHashTable *, gpointer);
typedef struct {
DropboxCommand dc;
gchar *command_name;
GHashTable *command_args;
- NautilusDropboxCommandResponseHandler handler;
+ CajaDropboxCommandResponseHandler handler;
gpointer handler_ud;
} DropboxGeneralCommand;
@@ -90,7 +90,7 @@ void dropbox_command_client_send_simple_command(DropboxCommandClient *dcc,
const char *command);
void dropbox_command_client_send_command(DropboxCommandClient *dcc,
- NautilusDropboxCommandResponseHandler h,
+ CajaDropboxCommandResponseHandler h,
gpointer ud,
const char *command, ...);
void
@@ -2,45 +2,45 @@
*
* dropbox-command-client.h
- * Header file for nautilus-dropbox-command.c
+ * Header file for caja-dropbox-command.c
*
@@ -2,45 +2,45 @@
*
- * This file is part of nautilus-dropbox.
+ * This file is part of caja-dropbox.
*
@@ -2,45 +2,45 @@
*
- * nautilus-dropbox is free software: you can redistribute it and/or modify
+ * caja-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
@@ -2,45 +2,45 @@
* (at your option) any later version.
*
- * nautilus-dropbox is distributed in the hope that it will be useful,
+ * caja-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
diff --git a/src/dropbox.c b/src/dropbox.c
index 0d59559..e5782e3 100644
--- a/src/dropbox.c
+++ b/src/dropbox.c
@@ -2,22 +2,22 @@
* Copyright 2008 Evenflow, Inc.
*
* dropbox.c
* Nautilus module registering functions for the Dropbox extension.
*
* This file is part of nautilus-dropbox.
*
* nautilus-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* nautilus-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
- * along with nautilus-dropbox. If not, see <http://www.gnu.org/licenses/>.
+ * along with caja-dropbox. If not, see <http://www.gnu.org/licenses/>.
*
*/
@@ -30,30 +30,30 @@
#include <gdk/gdk.h>
#include <gtk/gtk.h>
-#include "nautilus-dropbox.h"
+#include "caja-dropbox.h"
static GType type_list[1];
void
-nautilus_module_initialize (GTypeModule *module) {
+caja_module_initialize (GTypeModule *module) {
g_print ("Initializing %s\n", PACKAGE_STRING);
- nautilus_dropbox_register_type (module);
- type_list[0] = NAUTILUS_TYPE_DROPBOX;
+ caja_dropbox_register_type (module);
+ type_list[0] = CAJA_TYPE_DROPBOX;
- dropbox_use_nautilus_submenu_workaround
- = (NAUTILUS_VERSION_MAJOR < 2 ||
- (NAUTILUS_VERSION_MAJOR == 2 && NAUTILUS_VERSION_MINOR <= 22));
+ dropbox_use_caja_submenu_workaround
+ = (CAJA_VERSION_MAJOR < 2 ||
+ (CAJA_VERSION_MAJOR == 2 && CAJA_VERSION_MINOR <= 22));
dropbox_use_operation_in_progress_workaround = TRUE;
}
void
-nautilus_module_shutdown (void) {
+caja_module_shutdown (void) {
g_print ("Shutting down dropbox extension\n");
}
void
-nautilus_module_list_types (const GType **types,
+caja_module_list_types (const GType **types,
int *num_types) {
*types = type_list;
*num_types = G_N_ELEMENTS (type_list);
@@ -2,22 +2,22 @@
*
* dropbox.c
- * Nautilus module registering functions for the Dropbox extension.
+ * Caja module registering functions for the Dropbox extension.
*
@@ -2,22 +2,22 @@
*
- * This file is part of nautilus-dropbox.
+ * This file is part of caja-dropbox.
*
@@ -2,22 +2,22 @@
*
- * nautilus-dropbox is free software: you can redistribute it and/or modify
+ * caja-dropbox is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
@@ -2,22 +2,22 @@
* (at your option) any later version.
*
- * nautilus-dropbox is distributed in the hope that it will be useful,
+ * caja-dropbox is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the